.. include:: ../README.rst

.. toctree::
   :hidden:

   design
   installation
   Getting Started <https://mybinder.org/v2/gh/delb-xml/delb-py/main?filepath=docs%2Fgetting_started.ipynb>
   api/index
   changes
   license
   genindex
   Code Repository <https://github.com/delb-xml/delb-py>
   Issue Tracker <https://github.com/delb-xml/delb-py/issues>
   Discussions <https://github.com/delb-xml/delb-py/discussions>
